import { Component } from '@angular/core';
import { AlertController } from '@ionic/angular';

@Component({
  selector: 'app-tab2',
  templateUrl: 'tab2.page.html',
  styleUrls: ['tab2.page.scss'],
  standalone: false,
})
export class Tab2Page {

  constructor(private alertController: AlertController) {}

  // 打开AI助手
  async openAIAssistant() {
    const alert = await this.alertController.create({
      header: 'AI旅行助手',
      message: '请告诉我您想了解的旅行信息或需求',
      inputs: [
        {
          name: 'question',
          type: 'text',
          placeholder: '例如：推荐北京的必去景点'
        }
      ],
      buttons: [
        {
          text: '取消',
          role: 'cancel'
        },
        {
          text: '发送',
          handler: (data) => {
            if (data.question) {
              this.simulateAIResponse(data.question);
            }
          }
        }
      ]
    });

    await alert.present();
  }

  // 模拟AI回复
  private simulateAIResponse(question: string) {
    console.log('用户问题:', question);
    // 这里应该是调用AI服务的实际代码
    setTimeout(() => {
      this.showAIResponse('根据您的需求，推荐以下景点：故宫、颐和园、798艺术区');
    }, 1000);
  }

  // 显示AI回复
  private async showAIResponse(message: string) {
    const alert = await this.alertController.create({
      header: 'AI回复',
      message: message,
      buttons: ['好的']
    });
    await alert.present();
  }

  // 打开社交圈子
  openSocialCircle() {
    console.log('打开社交圈子页面');
    // 这里可以添加导航到社交圈子的逻辑
    this.showAlert('功能提示', '即将打开旅行社交圈功能');
  }

  // 创建新帖子
  async createNewPost() {
    const alert = await this.alertController.create({
      header: '分享旅行故事',
      inputs: [
        {
          name: 'content',
          type: 'textarea',
          placeholder: '写下你的旅行见闻...'
        }
      ],
      buttons: [
        {
          text: '取消',
          role: 'cancel'
        },
        {
          text: '发布',
          handler: (data) => {
            if (data.content) {
              this.showAlert('发布成功', '您的分享已发布到社交圈');
            }
          }
        }
      ]
    });

    await alert.present();
  }

  // 通用提示框
  private async showAlert(header: string, message: string) {
    const alert = await this.alertController.create({
      header,
      message,
      buttons: ['好的']
    });
    await alert.present();
  }
}
